@@ -59,8 +59,8 @@ class Actions : public QObject
 {
     Q_OBJECT
 public:
-    Actions(QObject *parent = 0);
-    ~Actions();
+    Actions(QObject *parent = nullptr);
+    ~Actions() override;
 
 
     QList<qulonglong> allActionIds() const;
