@@ -20,7 +20,7 @@
     </message>
     <message>
         <location filename="../default_model.cpp" line="143"/>
-        <source>Id</source>
+        <source>ID</source>
         <translation>Identif.</translation>
     </message>
     <message>
@@ -196,14 +196,16 @@ Opravdu to chcete?</translation>
     <message>
         <location filename="../main.cpp" line="51"/>
         <source>Platform Unsupported</source>
-        <translation type="unfinished"></translation>
+        <translation>Nepodporovaná platforma</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="52"/>
         <source>LXQt globalkeys are currently unsupported under Wayland.
 
 Global shortcuts can be configured in the settings of the compositor instead.</source>
-        <translation type="unfinished"></translation>
+        <translation>LXQt globální klávesové zkratky jsou v tuto chvíli nepodporované pod Wayland.
+
+Namísto toho je možné jejich nastavení provádět v nastavení kompozitoru.</translation>
     </message>
 </context>
 </TS>
