@@ -20,7 +20,7 @@
     </message>
     <message>
         <location filename="../default_model.cpp" line="143"/>
-        <source>Id</source>
+        <source>ID</source>
         <translation>Azonosító</translation>
     </message>
     <message>
@@ -196,7 +196,7 @@ Akarja folytatni?</translation>
     <message>
         <location filename="../main.cpp" line="51"/>
         <source>Platform Unsupported</source>
-        <translation type="unfinished"></translation>
+        <translation>Nem támogatott platform</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="52"/>
