@@ -20,7 +20,7 @@
     </message>
     <message>
         <location filename="../default_model.cpp" line="143"/>
-        <source>Id</source>
+        <source>ID</source>
         <translation>Endagamapeesa</translation>
     </message>
     <message>
@@ -179,12 +179,12 @@
         <translation>Mala</translation>
     </message>
     <message>
-        <location filename="../main_window.cpp" line="191"/>
+        <location filename="../main_window.cpp" line="194"/>
         <source>Restore Default</source>
         <translation>Zawo ebya bulijjo</translation>
     </message>
     <message>
-        <location filename="../main_window.cpp" line="192"/>
+        <location filename="../main_window.cpp" line="195"/>
         <source>Your defined shortcuts will be removed.
 Do you want to proceed?</source>
         <translation>Bye wetegekera bijja okugyibwawo.
