@@ -20,8 +20,8 @@
     </message>
     <message>
         <location filename="../default_model.cpp" line="143"/>
-        <source>Id</source>
-        <translation>Id</translation>
+        <source>ID</source>
+        <translation>ID</translation>
     </message>
     <message>
         <location filename="../default_model.cpp" line="146"/>
@@ -196,14 +196,16 @@ Volètz contunhar ?</translation>
     <message>
         <location filename="../main.cpp" line="51"/>
         <source>Platform Unsupported</source>
-        <translation type="unfinished"></translation>
+        <translation>Platafòrma incompatibla</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="52"/>
         <source>LXQt globalkeys are currently unsupported under Wayland.
 
 Global shortcuts can be configured in the settings of the compositor instead.</source>
-        <translation type="unfinished"></translation>
+        <translation>Los acorchis globals de LXQt son pas preses en carga per ara amb Wayland.
+
+Podètz configurar los acorchis globals dins los paramètres del compositor a la plaça.</translation>
     </message>
 </context>
 </TS>
