@@ -34,17 +34,15 @@
 #include "meta_types.h"
 #include "core.h"
 
-#include <errno.h>
+#include <cerrno>
 #include <getopt.h>
-#include <string.h>
+#include <cstring>
 #include <unistd.h>
-#include <stdio.h>
+#include <cstdio>
 #include <syslog.h>
-#include <stdlib.h>
+#include <cstdlib>
 #include <libgen.h> // for basename()
 
-#define DEFAULT_CONFIG ".config/lxqt/globalkeyshortcuts.conf"
-
 
 int main(int argc, char *argv[])
 {
@@ -60,14 +58,14 @@ int main(int argc, char *argv[])
 
     static struct option longOptions[] =
     {
-        {"no-daemon", no_argument, 0, 'n'},
-        {"daemon", no_argument, 0, 'd'},
-        {"use-syslog", no_argument, 0, 's'},
-        {"log-level", required_argument, 0, 'l'},
-        {"multiple-actions-behaviour", required_argument, 0, 'm'},
-        {"config-file", required_argument, 0, 'f'},
-        {"help", no_argument, 0, 'h'},
-        {0, 0, 0, 0}
+        {"no-daemon", no_argument, nullptr, 'n'},
+        {"daemon", no_argument, nullptr, 'd'},
+        {"use-syslog", no_argument, nullptr, 's'},
+        {"log-level", required_argument, nullptr, 'l'},
+        {"multiple-actions-behaviour", required_argument, nullptr, 'm'},
+        {"config-file", required_argument, nullptr, 'f'},
+        {"help", no_argument, nullptr, 'h'},
+        {nullptr, 0, nullptr, 0}
     };
 
     for (;;)
@@ -212,7 +210,7 @@ int main(int argc, char *argv[])
                "  --config-file=FILENAME\n"
                "      Use config file FILENAME. Can be used several times.\n"
                "      The last loaded file is used to save settings.\n"
-               "      Default is: ${HOME}/" DEFAULT_CONFIG "\n"
+               "      Default is: ${XDG_CONFIG_HOME}/lxqt/globalkeyshortcuts.conf\n"
                "\n"
                "  --help\n"
                "  -h\n"
@@ -235,13 +233,6 @@ int main(int argc, char *argv[])
     int ignoreIt = chdir((home && *home) ? home : "/");
     (void)ignoreIt;
 
-    if (configFiles.empty() && home && *home)
-    {
-        if( ! QFile::exists(QString::fromLocal8Bit(home) + QLatin1Char('/') + QLatin1String(DEFAULT_CONFIG)) ) //Load default settings
-            configFiles.push_back(QStringLiteral("/etc/xdg/lxqt/globalkeyshortcuts.conf"));
-        configFiles.push_back(QString::fromLocal8Bit(home) + QLatin1Char('/') + QLatin1String(DEFAULT_CONFIG));
-    }
-
     LXQt::Application app(argc, argv);
 
     Core core(runAsDaemon || useSyslog, minLogLevelSet, minLogLevel, configFiles, multipleActionsBehaviourSet, multipleActionsBehaviour);
